@@ -27,7 +27,7 @@ class RestClientMetaClass(type):
     def _generate_create_object_func(cls, resource_field_name, rest_resource):
         if "create" not in rest_resource.methods:
             return
-        func_name = "create_{0}".format(rest_resource.name)
+        func_name = rest_resource.method_names["create"]
         required_args = rest_resource.required_args
         func = cls._generate_resource_func(
             func_name,
@@ -40,7 +40,7 @@ class RestClientMetaClass(type):
     def _generate_list_func(cls, resource_field_name, rest_resource):
         if "list" not in rest_resource.methods:
             return
-        func_name = "get_{0}".format(rest_resource.plural_name)
+        func_name = rest_resource.method_names["list"]
         required_args = rest_resource.required_args
         func = cls._generate_resource_func(
             func_name,
@@ -52,7 +52,7 @@ class RestClientMetaClass(type):
     def _generate_get_object_func(cls, resource_field_name, rest_resource):
         if "detail" not in rest_resource.methods:
             return
-        func_name = 'get_{0}'.format(rest_resource.name)
+        func_name = rest_resource.method_names["object"]
         required_args = rest_resource.required_args + \
             [rest_resource.object_arg]
         func = cls._generate_resource_func(
@@ -65,7 +65,7 @@ class RestClientMetaClass(type):
     def _generate_delete_object_func(cls, resource_field_name, rest_resource):
         if "delete" not in rest_resource.methods:
             return
-        func_name = 'delete_{0}'.format(rest_resource.name)
+        func_name = rest_resource.method_names["delete"]
         required_args = rest_resource.required_args + \
             [rest_resource.object_arg]
         func = cls._generate_resource_func(
@@ -78,7 +78,7 @@ class RestClientMetaClass(type):
     def _generate_update_object_func(cls, resource_field_name, rest_resource):
         if "update" not in rest_resource.methods:
             return
-        func_name = 'update_{0}'.format(rest_resource.name)
+        func_name = rest_resource.method_names["update"]
         required_args = rest_resource.required_args + \
             [rest_resource.object_arg]
         func = cls._generate_resource_func(
@@ -166,22 +166,44 @@ class Client(object):
     the returned JSON object, for example: ::
 
         >>>client.get_account(acct_id)
-        {u'auth_token': u'abc437daf8517d0454cc984f6f09daf3',
+        {u'auth_token': u'abc437d000007d0454cc984f6f09daf3',
          u'data': {u'billing_mode': u'normal',
           u'caller_id': {},
           u'caller_id_options': {},
-          u'id': u'c4f64412ad0057222c12559a3e7da011',
+          u'id': u'c4f64412ad0057222c0009a3e7da011',
           u'media': {u'bypass_media': u'auto'},
           u'music_on_hold': {},
           u'name': u'test3',
           u'notifications': {},
-          u'realm': u'4c8b50.sip.2600hz.com',
+          u'realm': u'4c8050.sip.2600hz.com',
           u'superduper_admin': False,
           u'timezone': u'America/Los_Angeles',
           u'wnm_allow_additions': False},
-         u'request_id': u'ea6441422fb85f67ad21db4f1e2326c1',
-         u'revision': u'3-c16dd0a629fe1da254fe1e7b3e5fb35a',
+         u'request_id': u'ea6441422fb85000ad21db4f1e2326c1',
+         u'revision': u'3-c16dd0a629fe1da0000e1e7b3e5fb35a',
          u'status': u'success'}
+
+    For each resource exposed by the kazoo api there are corresponding methods
+    on the client. For example, for the 'callflows' resource the
+    correspondence is as follows.
+
+        GET /accounts/{account_id}/callflows -> client.get_callflows(acct_id)
+        GET /accounts/{account_id}/callflows/{callflow_id} -> client.get_callflow(acct_id, callflow_id)
+        PUT /accounts/{account_id}/callflows/ -> client.create_callflow(acct_id, data)
+        POST /account/{account_id}/callflows/{callflow_id} -> client.update_callflow(acct_id, data)
+        DELETE /account/{account_id}/callflows/{callflow_id} -> client.delete_callflow(acct_id, callflow_id)
+
+    Some resources do not have all methods available, in which case they are
+    not present on the client.
+
+    There are also some resources which don't quite fit this paradigm, they are:
+
+        GET /accounts/{account_id}/children -> client.get_account_children(acct_id)
+        GET /accounts/{account_id}/descendants -> client.get_account_descendants(acct_id)
+        GET /accounts/{account_id}/devices/status -> client.get_all_devices_status(acct_id)
+        GET /accounts/{account_id}/servers/{server_id}/deployment -> client.get_deployment(acct_id, server_id)
+        GET /accounts/{account_id}/users/hotdesk -> client.get_hotdesk(acct_id)
+
     """
     __metaclass__ = RestClientMetaClass
     BASE_URL = "http://api.2600hz.com:8000/v1"
@@ -220,9 +242,12 @@ class Client(object):
     _local_resources_resource = RestResource(
         "local_resource",
         "/accounts/{account_id}/local_resources/{resource_id}")
-    _media_resource = RestResource("medium",
+    _media_resource = RestResource("media",
                                    "/accounts/{account_id}/media/{media_id}",
-                                   plural_name="media")
+                                   plural_name="media",
+                                   method_names={
+                                       "list": "get_all_media"
+                                   })
     _menus_resource = RestResource("menu",
                                    "/accounts/{account_id}/menus/{menu_id}")
     _phone_number_resource = RestResource(
